<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1, viewport-fit=cover"/>
    <meta http-equiv="X-UA-Compatible" content="ie=edge"/>
    <title>{{ title }}</title>
    <!-- CSS files -->
    <link href="{{ url_for('public', path='vendor/tabler/css/tabler.'+minify+'css') }}" rel="stylesheet"/>
    <link href="{{ url_for('public', path='vendor/tabler/css/tabler-icons.'+minify+'css') }}" rel="stylesheet"/>
    <link href="{{ url_for('public', path='css/main.css') }}" rel="stylesheet"/>
    {% block styles %}
    {% endblock %}
</head>
<body data-bs-theme="dark">
<div class="page">
    <!-- Sidebar -->
    {% include "components/aside.html" %}
    <!-- Navbar -->
    {% include "components/header.html" %}

    <div class="page-wrapper">
        <!-- Page header -->
        <div class="page-header d-print-none">
            <div class="container-fluid">
                <div class="row g-2 align-items-center">
                    <div class="col">
                        <!-- Page pre-title -->
                        <div class="page-pretitle">
                            {{ subtitle or '' }}
                        </div>
                        <h2 class="page-title">
                            {{ (obj and model.__name__+': '+obj.repr()) or (model and model.__name__) or title or '' }}
                        </h2>
                    </div>
                    <!-- Page title actions -->
                    {% include "components/global_actions.html" %}
                </div>
            </div>
        </div>
        <!-- Page body -->
        <div class="page-body">
            <div class="container-fluid">
                {% block body %}
                {% endblock %}
            </div>
        </div>
        {% include "components/footer.html" %}
    </div>
</div>

<script src="{{ url_for('public', path='vendor/tabler/js/dark-theme.'+minify+'js') }}"></script>
<script src="{{ url_for('public', path='vendor/jQuery/jquery.'+minify+'js') }}"></script>
<script src="{{ url_for('public', path='vendor/tabler/js/tabler.'+minify+'js') }}" defer></script>
{% block scripts %}
{% endblock %}
</body>
</html>