{% extends "layout.html" %}

{% from "views/table.html" import table with context %}
{% from "views/form.html" import form with context %}

{% block body %}
    {{ form(model=model) }}
    {% for bfm in bfms %}
        {% with modal_model=bfm %}
            {% include "components/modal.html" %}
        {% endwith %}
        {{ table(model=bfm) }}
    {% endfor %}
{% endblock %}
