<div class="form-group mb-3">
    <label class="form-label">{{ label }}</label>
    <input {% if not null %}required{% endif %} type="color" class="form-control form-control-color" name="{{ name }}"
           placeholder="{{ placeholder }}" {% if disabled %}disabled{% endif %} value="{{ value }}">
    {% if help_text %}
        <small class="form-hint">
            {{ help_text }}
        </small>
    {% endif %}
</div>