<div class="col-auto ms-auto d-print-none">
    <div class="btn-list">
        {% if request.scope['endpoint'].__name__ in ['index'] and model %}
        <a href="#" class="btn btn-primary d-none d-sm-inline-block" data-bs-toggle="modal"
           data-bs-target="#modal-{{ model.__name__ }}">
            <svg xmlns="http://www.w3.org/2000/svg" class="icon" width="24" height="24"
                 viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none"
                 stroke-linecap="round" stroke-linejoin="round">
                <path stroke="none" d="M0 0h24v24H0z" fill="none"/>
                <path d="M12 5l0 14"/>
                <path d="M5 12l14 0"/>
            </svg>
            New {{ model.__name__ }}
        </a>
        <a href="#" class="btn btn-primary d-sm-none btn-icon" data-bs-toggle="modal"
           data-bs-target="#modal-{{ model.__name__ }}" aria-label="Create new {{ model.__name__ }}">
            <i class="ti ti-plus"></i>
        </a>
        {% endif %}
    </div>
</div>