<footer class="footer footer-transparent d-print-none py-1">
    <div class="container-fluid">
        <div class="row text-center align-items-center flex-row-reverse">
            <div class="col-lg-auto ms-lg-auto">
                <ul class="list-inline list-inline-dots mb-0">
                    <li class="list-inline-item">
                        <a class="link-secondary" rel="noopener" target="_blank" href="https://pypi.org/project/femto-admin/{{ meta.ver }}/">v{{ meta.ver }}</a>
                    </li>
                </ul>
            </div>
            <div class="col-12 col-lg-auto mt-3 mt-lg-0">
                <ul class="list-inline list-inline-dots mb-0">
                    <li class="list-inline-item">
                        <a href="https://github.com/mixartemev/femto-admin" target="_blank" class="link-secondary" rel="noopener">Femto Admin</a>
                        © {{ meta.year }}
                    </li>
                </ul>
            </div>
        </div>
    </div>
</footer>