<select class="form-select" name="{{ key }}{{ field.multiple and '[]' }}" id="{{ 'form-select-'+key }}" {{ field.multiple and 'multiple' }}>
    {% for val, name in field.options.items() %}
        <option value="{{ val }}" {% if val == (value and (value.pk or value)) %}selected{% endif %}>
            {{ name }}
        </option>
    {% endfor %}
</select>
{% if help_text %}
    <div class="mt-2">
        <small class="form-hint">{{ help_text }}</small>
    </div>
{% endif %}
{#{% include "components/select.html" %}#}
